DeserializerConfig

Struct DeserializerConfig 

pub struct DeserializerConfig { /* private fields */ }
Configures how MessagePack is deserialized.

The configuration is independent of the input so it can be created once (even as a constant) and used for many inputs. The method from_slice works like the function of the same name. To read multiple items with the configuration create a Deserializer with Deserializer::from_slice_with_config.

use deser_msgpack::DeserializerConfig;

const CONFIG: DeserializerConfig = DeserializerConfig::new();
assert_eq!(CONFIG.from_slice::<Vec<u32>>(&[0x92, 0x01, 0x02]).unwrap(), [1, 2]);

Implementations

Source

impl DeserializerConfig

pub const fn new() -> DeserializerConfig

Creates the default configuration.

pub fn from_slice<'de, T: Deserialize<'de>>( &self, input: &'de [u8], ) -> Result<T, Error>

Deserializes a value from MessagePack.

See from_slice.

Source

impl DeserializerConfig

pub fn reader<R: Read>(&self, reader: R) -> Reader<R, StreamDeserializer>

Creates a reader of a stream of items (see deser::io::Reader).

See StreamDeserializer for how the stream is read.

pub fn from_reader<T: DeserializeOwned, R: Read>( &self, reader: R, ) -> Result<T, Error>

Deserializes an item from a reader.

See from_reader.