pub struct Ext {
pub kind: i8,
pub data: Vec<u8>,
}Expand description
A MessagePack extension value: a type and binary data.
Extensions whose type the format does not understand are passed through
deser as extension atoms of this type. Their fallback is the binary
data, so an extension deserializes into Vec<u8> if the type is not of
interest. Values of this type are written as extensions.
use deser_msgpack::Ext;
let bytes = deser_msgpack::to_vec(&Ext::new(7, vec![1, 2, 3])).unwrap();
assert_eq!(bytes, [0xc7, 0x03, 0x07, 0x01, 0x02, 0x03]);
let value: Ext = deser_msgpack::from_slice(&bytes).unwrap();
assert_eq!(value, Ext::new(7, vec![1, 2, 3]));Timestamps (type -1) are converted to and from
Timestamp instead. They are still
accepted by this type which then holds their encoding.
Fields
kind: i8The type of the extension (-128 to -1 are reserved by the
specification).
data: Vec<u8>The data of the extension.
Implementations