pub struct Serializer { /* private fields */ }Expand description
Serializes values into MessagePack.
Every call to serialize writes an item, the items
follow each other (which is how MessagePack streams work).
use deser_msgpack::Serializer;
let mut serializer = Serializer::new();
serializer.serialize(&1u32).unwrap();
serializer.serialize(&"hi").unwrap();
assert_eq!(serializer.finish(), [0x01, 0xa2, b'h', b'i']);The serializer is also the stream serializer of MessagePack (see
StreamSerializer): the output can be taken
while values are written, and large values can be written in parts.
The output of arrays and maps whose length is not known upfront (and of
maps in canonical mode) is held back until they are complete, as their
header or the order of their entries is only known then. To write to
a Write use SerializerConfig::writer.
Implementations
Sourceimpl Serializer
impl Serializer
Sourcepub fn new() -> Serializer
pub fn new() -> Serializer
Creates a serializer.
Sourcepub fn with_config(config: SerializerConfig) -> Serializer
pub fn with_config(config: SerializerConfig) -> Serializer
Creates a serializer with the given configuration.
Sourcepub fn config(&self) -> &SerializerConfig
pub fn config(&self) -> &SerializerConfig
Returns the configuration.
Sourcepub fn serialize<T: Serialize + ?Sized>(
&mut self,
value: &T,
) -> Result<(), Error>
pub fn serialize<T: Serialize + ?Sized>( &mut self, value: &T, ) -> Result<(), Error>
Serializes a value.
If the value fails to serialize, nothing is written.